import React from "react";

/**
 * [*] A Checkbox Component
 * 
 * [*] when the label is clicked => The checkbox will be checked
 * 
 * [*] for each item(row) you have to put the following in App.tsx:
 *    const [isCheckedA, setIsCheckedA] = useState(true);
      const handleChangeA = (e: React.ChangeEvent<HTMLInputElement>) => {
      setIsCheckedA(e.target.checked);
      }; 
 * 
 * [*] to create this component, you have to provide the following:
 * [1] label
 * [2] if the item is checked or not.
 * 
 * [*] A good example will be:
const App: React.FC = () => 
{
    const [isCheckedA, setIsCheckedA] = useState(true);
    const handleChangeA = (e: React.ChangeEvent<HTMLInputElement>) => {
    setIsCheckedA(e.target.checked);
    };

    const [isCheckedB, setIsCheckedB] = useState(true);
    const handleChangeB = (e: React.ChangeEvent<HTMLInputElement>) => {
    setIsCheckedB(e.target.checked);
    };

    return (
      <div className="App">
        
        <Checkbox
          handleChange={handleChangeA}
          isChecked={isCheckedA}
          label=" Leo Tolstoy "
        />

        <Checkbox
          handleChange={handleChangeB}
          isChecked={isCheckedB}
          label=" Fyodor Dostoevsky "
        />

      </div>
    );
};

*/

interface Props {
  isChecked: boolean;
  handleChange: (event: React.ChangeEvent<HTMLInputElement>) => void;
  label: string;
}

const Checkbox = (props: Props) => {
  return (
    <div>
      <input
        type="checkbox"
        id={props.label}
        checked={props.isChecked}
        onChange={props.handleChange}
      />
      <label htmlFor={props.label}>{props.label}</label>
    </div>
  );
};
export default Checkbox;
